summaryrefslogtreecommitdiffstats
path: root/kjsembed/bindings/image_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/bindings/image_imp.h')
-rw-r--r--kjsembed/bindings/image_imp.h22
1 files changed, 11 insertions, 11 deletions
diff --git a/kjsembed/bindings/image_imp.h b/kjsembed/bindings/image_imp.h
index 94d84e01..39cb7031 100644
--- a/kjsembed/bindings/image_imp.h
+++ b/kjsembed/bindings/image_imp.h
@@ -32,7 +32,7 @@ namespace KJSEmbed {
namespace Bindings {
/**
* Methods for the TTQImage binding.
*
* @author Richard Moore, rich@kde.org
* @version $Id$
@@ -66,27 +66,27 @@ public:
private:
- TTQString filename() const;
- TTQString format() const;
+ TQString filename() const;
+ TQString format() const;
int width() const;
int height() const;
int depth() const;
bool isOk() const;
- TTQPixmap pixmap() const;
+ TQPixmap pixmap() const;
- bool load( const TTQString &filename );
- bool save( const TTQString &filename, const TTQString &fmt );
- void setFormat( const TTQString &fmt );
+ bool load( const TQString &filename );
+ bool save( const TQString &filename, const TQString &fmt );
+ void setFormat( const TQString &fmt );
void smoothScale( int w, int h );
void smoothScaleMin( int w, int h );
- void setPixmap( const TTQPixmap &pix );
+ void setPixmap( const TQPixmap &pix );
int mid;
- TTQImage img; // this is a temp!!!
- TTQString nm;
- TTQString fmt;
+ TQImage img; // this is a temp!!!
+ TQString nm;
+ TQString fmt;
};
} // namespace
@@ -32,7 +32,7 @@ namespace KJSEmbed {
namespace Bindings {
/**
- * Methods for the TTQImage binding.
+ * Methods for the TQImage binding.
*
* @author Richard Moore, rich@kde.org